axomatic: Axomatix

Description Usage Arguments Examples

View source: R/axomatic.r

Description

Used to make defining x axis, y axis, and plot shape (square, rectangular, etc) It uses functions axis_x() and axis_y() to make two axes, and then lets the user specify the shape of the plot. The function is used and added as a ggplot object.

Usage

1
axomatic(x, y, ratio = 1, scaleSize = T)

Arguments

x

an x-axis specified with the function axis_x (or aximaticultimatic())

y

an y-axis specified with the function axis_y (or aximaticultimatic())

ratio

the ratio between the x and y axis. Defaults to 1 (a square)

scaleSize

if the ratio is for physical graph size (T, default) or the va

Examples

1
axomatic(x_axis(0,20),y_axis(1000, 10000))

Eiriksen/EirikFunctions documentation built on Oct. 30, 2019, 5:31 p.m.