Description Usage Arguments Examples
Used to make defining x axis, y axis, and plot shape (square, rectangular, etc) It uses functions axis_x() and axis_y() to make two axes, and then lets the user specify the shape of the plot. The function is used and added as a ggplot object.
1 | axomatic(x, y, ratio = 1, scaleSize = T)
|
x |
an x-axis specified with the function axis_x (or aximaticultimatic()) |
y |
an y-axis specified with the function axis_y (or aximaticultimatic()) |
ratio |
the ratio between the x and y axis. Defaults to 1 (a square) |
scaleSize |
if the ratio is for physical graph size (T, default) or the va |
1 | axomatic(x_axis(0,20),y_axis(1000, 10000))
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.